@@ -115,6 +115,7 @@ class Utils(object):
 			raise DockerError('Login to docker failed while getting ECR authorization token: ' + str(e), None)
 
 		cls.docker_auth_config = {'username': ecr_username, 'password': ecr_password}
+		cls.last_time_docker_login = cls.get_timestamp()
 
 		"""command = ['docker', 'login', '-u', ecr_username, '--password-stdin', registry]
 		if sys.version_info < (3, 0):
@@ -158,7 +159,10 @@ class Utils(object):
 		p.wait()
 		"""
 		try:
-			docker_client.images.pull(image, auth_config=cls.docker_auth_config)
+			if image.find('amazonaws.com') > 0:
+				docker_client.images.pull(image, auth_config=cls.docker_auth_config)
+			else: 
+				docker_client.images.pull(image)
 		except Exception as e:
 			# pull failed, check if the image exists, if true then use the current version, otherwise raise error
 			try:
